@@ -4,6 +4,7 @@ Utils for working with grammatical tags.
 """
 from __future__ import absolute_import, unicode_literals
 import collections
+import threading
 
 try:
     from sys import intern
@@ -403,7 +404,6 @@ class OpencorporaTag(object):
 
         """
         gr = dict((name, parent) for (name, parent, alias, description) in dict_grammemes)
-        cls.KNOWN_GRAMMEMES = set(gr.keys())
 
         # figure out parents & children
         children = collections.defaultdict(set)
@@ -413,18 +413,21 @@ class OpencorporaTag(object):
             if gr.get(parent, None): # parent's parent
                 children[gr[parent]].add(name)
 
-        # expand EXTRA_INCOMPATIBLE
-        for grammeme, g_set in cls._EXTRA_INCOMPATIBLE.items():
-            for g in g_set.copy():
-                g_set.update(children[g])
+        with threading.RLock():
+            cls.KNOWN_GRAMMEMES = set(gr.keys())
 
-        # fill GRAMMEME_INDICES and GRAMMEME_INCOMPATIBLE
-        for index, (name, parent, alias, description) in enumerate(dict_grammemes):
-            cls._GRAMMEME_INDICES[name] = index
-            incompatible = cls._EXTRA_INCOMPATIBLE.get(name, set())
-            incompatible = (incompatible | children[parent]) - set([name])
+            # expand EXTRA_INCOMPATIBLE
+            for grammeme, g_set in cls._EXTRA_INCOMPATIBLE.items():
+                for g in g_set.copy():
+                    g_set.update(children[g])
 
-            cls._GRAMMEME_INCOMPATIBLE[name] = frozenset(incompatible)
+            # fill GRAMMEME_INDICES and GRAMMEME_INCOMPATIBLE
+            for index, (name, parent, alias, description) in enumerate(dict_grammemes):
+                cls._GRAMMEME_INDICES[name] = index
+                incompatible = cls._EXTRA_INCOMPATIBLE.get(name, set())
+                incompatible = (incompatible | children[parent]) - set([name])
+
+                cls._GRAMMEME_INCOMPATIBLE[name] = frozenset(incompatible)
 
     # XXX: do we still need these methods?
     @classmethod
@@ -465,6 +468,15 @@ class OpencorporaTag(object):
             grammemes = self._NUMERAL_AGREEMENT_GRAMMEMES[4]
         return grammemes
 
+    #@classmethod
+    #def _clone_class(cls):
+    #    Tag = type(cls.__name__, (cls,), {
+    #         'KNOWN_GRAMMEMES': cls.KNOWN_GRAMMEMES.copy(),
+    #    })
+    #    # copyreg.pickle(Tag, pickle_tag)
+    #    return Tag
+
+
 
 class CyrillicOpencorporaTag(OpencorporaTag):
     """
@@ -521,7 +533,6 @@ class CyrillicOpencorporaTag(OpencorporaTag):
         for name, parent, alias, description in dict_grammemes:
             cls._GRAMMEME_ALIAS_MAP[name] = alias
 
-
 registry = dict()
 
 for tag_type in [CyrillicOpencorporaTag, OpencorporaTag]:
